==> scummvm_2.5.1+dfsg.orig.tar.xz: scummvm-2.5.1/devtools/create_kyradat/resources/lok_dos_cd_german.h <==
static const char *const k1IntroStringsDOSCDGerman[52] = {
	"This is a text test - 1",
	"This is a text test - 2",
	"Sei gegr""\x81\xE1""t, Kallak...",
	"...M""\x84""chtiger Anf""\x81""hrer der k""\x94""niglichen Mystiker!",
	"Habe ich dich erschreckt?",
	"Malcolm!",
	"Ich habe gestern von deiner Flucht geh""\x94""rt.",
	"Ich habe dich fr""\x81""her erwartet.",
	"Warum sollte ich mich beeilen?",
	"Ich herrsche ""\x81""ber dieses Land!",
	"Dein mickriger Fluch h""\x84""lt mich nicht zur""\x81""ck.",
	"So, erschlag mich doch!",
	"Ich habe nur noch wenig Magie ""\x81""brig.",
	"Ich werde dir zu Leibe r""\x81""cken, zweifle blo""\xE1"" nicht daran...",
	"...du bist jetzt aus Stein...",
	"...Ich lasse dir allein deine Augen.",
	"F""\x81""r Kyrandia vergie""\xE1""e ich nicht eine Tr""\x84""ne...",
	"...aber deine will ich dir nicht nehmen.",
	"Malcolm der Hofnarr ist ausgebrochen!",
	"Er beherrscht nun den Kyragem...",
	"...die Quelle aller Magie in Kyrandia!",
	"",
	"Wie kannst du es wagen, MICH umzuwerfen!",
	"Nicht doch, etwas Besonderes f""\x81""r dich...",
	"Was f""\x81""r ein l""\x84""cherlicher Fluch!",
	"Ich warne dich vorher.",
	"Springe nicht auf DIESEN Baum!",
	"Klettre nicht auf diesen Baum, kleines Eichh""\x94""rnchen!",
	"Buuh!",
	"So ist es viel lustiger...",
	"...nicht wahr?",
	"Ha ha ha...",
	"Sind Finger nicht 'was Tolles?",
	"Es ist gro""\xE1""artig, am Leben zu sein!",
	"Brandon!",
	"Gro""\xE1""vater! Wir haben es geschafft!",
	"Nein! DU hast es geschafft!",
	"Lang lebe K""\x94""nig Brandon!",
	"Lang leben die k""\x94""niglichen Mystiker!",
	"Bauen wir Kyrandia wieder auf!",
	"Eine gute Idee!",
	"Als meine erste k""\x94""nigliche Proklamation,...",
	"...erkl""\x84""re ich Sandalen zur offiziellen Fu""\xE1""bekleidung Kyrandias!",
	"Sehr weise, Brandon!",
	"Das Land ist nicht l""\x84""nger in Trauer!",
	"Und deine Freunde sind gerettet.",
	"Liebe Brynn...",
	"Malcolm ist ausgebrochen!",
	"Er wird bald zu mir kommen.",
	"Bitte hilf Brandon...",
	"",
	""
};

static const StringListProvider k1IntroStringsDOSCDGermanProvider = { ARRAYSIZE(k1IntroStringsDOSCDGerman), k1IntroStringsDOSCDGerman };

static const char *const k1ItemNamesDOSCDGerman[108] = {
	"Granat",
	"Amethyst",
	"Aquamarin",
	"Diamant",
	"Smaragd",
	"Perle",
	"Rubin",
	"Peridot",
	"Saphir",
	"Opal",
	"Topas",
	"Onyx",
	"Sonnenstein",
	"Mondstein",
	"Regenbogenstein",
	"Magnetstein",
	"Rose",
	"Tulpe",
	"Orchidee",
	"Silberne Rose",
	"Silberne Statuette",
	"Silberm""\x81""nze",
	"Goldm""\x81""nze",
	"Goldring",
	"Der Kelch des K""\x94""nigs",
	"Kienapfel",
	"Eichel",
	"Walnu""\xE1",
	"Immerleuchtende Feuerbeeren",
	"Feuerbeeren",
	"Feuerbeeren",
	"Feuerbeeren",
	"Feuerbeeren",
	"Feuerbeeren",
	"Fisch",
	"Fischgr""\x84""te",
	"Hammelkeule",
	"Knochen",
	"Apfel",
	"Apfelgriebsch",
	"Heidelbeeren",
	"Pilz",
	"Notiz",
	"Murmel",
	"S""\x84""ge",
	"Henkelkreuz",
	"Feder",
	"Ei",
	"Blatt",
	"Kleeblatt",
	"Sternschnuppe",
	"Kristallkugel",
	"Tr""\x84""ne",
	"Spiegel",
	"Eisst""\x81""ck",
	"Fl""\x94""te",
	"Sanduhr",
	"Eisenschl""\x81""ssel",
	"Jadeschl""\x81""ssel",
	"Obsidianschl""\x81""ssel",
	"Roter Trank",
	"Roter Trank",
	"Blauer Trank",
	"Blauer Trank",
	"Gelber Trank",
	"Gelber Trank",
	"Gr""\x81""ner Trank",
	"Oranger Trank",
	"Violetter Trank",
	"Regenbogentrank",
	"S""\x81\xE1""wasser",
	"S""\x81\xE1""wasser",
	"Salzwasser",
	"Salzwasser",
	"Mineralwasser",
	"Mineralwasser",
	"Magisches Wasser",
	"Magisches Wasser",
	"Leere Flasche",
	"Leere Flasche",
	"Schriftrolle",
	"Schriftrolle",
	"Schriftrolle",
	"Schriftrolle",
	"Schriftrolle",
	"Schriftrolle",
	"Schriftrolle",
	"Schriftrolle",
	"Schriftrolle",
	"Schriftrolle",
	"Pergamentfetzen",
	"Pergamentfetzen",
	"Pergamentfetzen",
	"Pergamentfetzen",
	"Pergamentfetzen",
	"Roter Weisenstein",
	"Oranger Weisenstein",
	"Gelber Weisenstein",
	"Gr""\x81""ner Weisenstein",
	"T""\x81""rkiser Weisenstein",
	"Blauer Weisenstein",
	"Violetter Weisenstein",
	"Schwerer Stein",
	"K""\x94""nigliche Krone",
	"K""\x94""nigliches Zepter",
	"Goldschl""\x81""ssel",
	"Unbekannter Gegenstand",
	""
};

static const StringListProvider k1ItemNamesDOSCDGermanProvider = { ARRAYSIZE(k1ItemNamesDOSCDGerman), k1ItemNamesDOSCDGerman };

static const char *const k1TakenStringsDOSCDGerman[2] = {
	" aufgenommen.",
	" aufgenommen."
};

static const StringListProvider k1TakenStringsDOSCDGermanProvider = { ARRAYSIZE(k1TakenStringsDOSCDGerman), k1TakenStringsDOSCDGerman };

static const char *const k1PlacedStringsDOSCDGerman[1] = {
	" abgelegt."
};

static const StringListProvider k1PlacedStringsDOSCDGermanProvider = { ARRAYSIZE(k1PlacedStringsDOSCDGerman), k1PlacedStringsDOSCDGerman };

static const char *const k1DroppedStringsDOSCDGerman[1] = {
	" fallengelassen."
};

static const StringListProvider k1DroppedStringsDOSCDGermanProvider = { ARRAYSIZE(k1DroppedStringsDOSCDGerman), k1DroppedStringsDOSCDGerman };

static const char *const k1NoDropStringsDOSCDGerman[2] = {
	"Hier kann nichts mehr abgelegt werden.",
	"Das kann hier nicht abgelegt werden."
};

static const StringListProvider k1NoDropStringsDOSCDGermanProvider = { ARRAYSIZE(k1NoDropStringsDOSCDGerman), k1NoDropStringsDOSCDGerman };

static const char *const k1PutDownStringDOSCDGerman[1] = {
	"Vielleicht sollte ich es erst hinlegen."
};

static const StringListProvider k1PutDownStringDOSCDGermanProvider = { ARRAYSIZE(k1PutDownStringDOSCDGerman), k1PutDownStringDOSCDGerman };

static const char *const k1WaitAmuletStringDOSCDGerman[1] = {
	"I nehme an, ich mu""\xE1"" warten, bis mein Amulett seine Kraft wiedererlangt."
};

static const StringListProvider k1WaitAmuletStringDOSCDGermanProvider = { ARRAYSIZE(k1WaitAmuletStringDOSCDGerman), k1WaitAmuletStringDOSCDGerman };

static const char *const k1BlackJewelStringDOSCDGerman[1] = {
	"Es ist ein Edelstein, aber warum ist er schwarz?"
};

static const StringListProvider k1BlackJewelStringDOSCDGermanProvider = { ARRAYSIZE(k1BlackJewelStringDOSCDGerman), k1BlackJewelStringDOSCDGerman };

static const char *const k1HealingTipStringDOSCDGerman[1] = {
	"Mann, das kann ganz n""\x81""tzlich sein, falls ich mich verletze!"
};

static const StringListProvider k1HealingTipStringDOSCDGermanProvider = { ARRAYSIZE(k1HealingTipStringDOSCDGerman), k1HealingTipStringDOSCDGerman };

static const char *const k1PoisonGoneStringDOSCDGerman[2] = {
	"Erstaunlich!",
	"Die Wirkung des Giftes hat nachgelassen!"
};

static const StringListProvider k1PoisonGoneStringDOSCDGermanProvider = { ARRAYSIZE(k1PoisonGoneStringDOSCDGerman), k1PoisonGoneStringDOSCDGerman };

static const char *const k1ThePoisonStringsDOSCDGerman[4] = {
	"Das Gift...",
	"Ich kann nicht atmen...",
	"Ich f""\x81""hle mich nicht besonders wohl...",
	"Die Schlange mu""\xE1"" \rgiftig gewesen sein!"
};

static const StringListProvider k1ThePoisonStringsDOSCDGermanProvider = { ARRAYSIZE(k1ThePoisonStringsDOSCDGerman), k1ThePoisonStringsDOSCDGerman };

static const char *const k1FluteStringsDOSCDGerman[2] = {
	"Klingt nicht besonders beeindruckend.",
	"Die letzte Note war hoch!"
};

static const StringListProvider k1FluteStringsDOSCDGermanProvider = { ARRAYSIZE(k1FluteStringsDOSCDGerman), k1FluteStringsDOSCDGerman };

static const char *const k1WispJewelStringsDOSCDGerman[2] = {
	"Im Moment f""\x81""hle ich mich dazu nicht in der Lage.",
	"Ich mu""\xE1"" wahrscheinlich erst mein(e)..."
};

static const StringListProvider k1WispJewelStringsDOSCDGermanProvider = { ARRAYSIZE(k1WispJewelStringsDOSCDGerman), k1WispJewelStringsDOSCDGerman };

static const char *const k1MagicJewelStringsDOSCDGerman[1] = {
	"Das war eigenartig."
};

static const StringListProvider k1MagicJewelStringsDOSCDGermanProvider = { ARRAYSIZE(k1MagicJewelStringsDOSCDGerman), k1MagicJewelStringsDOSCDGerman };

static const char *const k1FlaskFullStringDOSCDGerman[1] = {
	"Die Flasche ist bereits voll."
};

static const StringListProvider k1FlaskFullStringDOSCDGermanProvider = { ARRAYSIZE(k1FlaskFullStringDOSCDGerman), k1FlaskFullStringDOSCDGerman };

static const char *const k1FullFlaskStringDOSCDGerman[4] = {
	"Die Flasche ist jetzt mit \rfrischem, klarem Wasser gef""\x81""llt.",
	"Die Flasche ist jetzt mit \rSalzwasser gef""\x81""llt.",
	"Die Flasche ist jetzt mit \rMineralwasser gef""\x81""llt.",
	"Magisches Wasser."
};

static const StringListProvider k1FullFlaskStringDOSCDGermanProvider = { ARRAYSIZE(k1FullFlaskStringDOSCDGerman), k1FullFlaskStringDOSCDGerman };

static const char *const k1OutroHomeStringDOSCDGerman[1] = {
	"Ab nach Hause"
};

static const StringListProvider k1OutroHomeStringDOSCDGermanProvider = { ARRAYSIZE(k1OutroHomeStringDOSCDGerman), k1OutroHomeStringDOSCDGerman };

static const char *const k1VeryCleverStringDOSCDGerman[1] = {
	"Sehr clever! Aber nichtige Versuche sind zum Scheitern verurteilt."
};

static const StringListProvider k1VeryCleverStringDOSCDGermanProvider = { ARRAYSIZE(k1VeryCleverStringDOSCDGerman), k1VeryCleverStringDOSCDGerman };

static const char *const k1GUIStringsDOSCDGerman[59] = {
	"Die Legende von Kyrandia",
	"Ein Spiel laden",
	"Dieses Spiel sichern",
	"Spielsteuerungen",
	"Spiel beenden",
	"Spiel wieder aufnehmen",
	"Spielsteuerungen",
	"Welches Spiel soll noch einmal geladen werden?",
	"W""\x84""hlen Sie den Platz zum Sichern aus.",
	"[ LEERER PLATZ ]",
	"Abbrechen",
	"Beschreibung des gesicherten Spiels eingeben.",
	"Sichern",
	"Ruhe in Frieden, Brandon.",
	"Soll das Spiel wirklich beendet werden?",
	"XXXXX",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"XXXXX",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"XXXXXXXXXXXXXXXXX",
	"XXXXXXXXXXXXXXXXX",
	"XXXXXXXXXXXX",
	"",
	"",
	"",
	"",
	"",
	"Hauptmen""\x81",
	"An",
	"Aus",
	"Ja",
	"Nein",
	"c""\x0F\x17""+r""\x0F\x17""+z""\x0F\x17""+""\x81\x0F\x17""+""\x89\x0F\x17""+""\x98\x0F\x17""+""\xA1\x0F\x17""+""\xAD\x0F\x17""+""\xBC\x0F\x17""+""\xCB\x0F\x17""+""\xD2\x0F\x17""+""\xDA\x0F\x17""+Schrittempo",
	"Textgeschwindigkeit",
	"Die Musik ist",
	"Die Soundeffekte sind",
	"Stimmen/Text"
};

static const StringListProvider k1GUIStringsDOSCDGermanProvider = { ARRAYSIZE(k1GUIStringsDOSCDGerman), k1GUIStringsDOSCDGerman };

static const char *const k1NewGameStringDOSCDGerman[1] = {
	"[ EIN NEUES SPIEL ANFANGEN ]"
};

static const StringListProvider k1NewGameStringDOSCDGermanProvider = { ARRAYSIZE(k1NewGameStringDOSCDGerman), k1NewGameStringDOSCDGerman };

static const char *const k1ConfigStringsDOSCDGerman[12] = {
	"am langsamsten",
	"langsam",
	"normal",
	"schnell",
	"am schnellsten",
	"Nur Text",
	"Nur Stimmen",
	"Stimmen & Text",
	"am langsamsten",
	"normal",
	"schnell",
	"anklickbar"
};

static const StringListProvider k1ConfigStringsDOSCDGermanProvider = { ARRAYSIZE(k1ConfigStringsDOSCDGerman), k1ConfigStringsDOSCDGerman };

==> scummvm_2.9.1+dfsg.orig.tar.xz: scummvm-2.9.1/devtools/create_kyradat/resources/lok_dos_cd_german.h <==
static const char *const k1IntroStringsDOSCDGerman[52] = {
	"This is a text test - 1",
	"This is a text test - 2",
	"Sei gegr""\x81\xE1""t, Kallak...",
	"...M""\x84""chtiger Anf""\x81""hrer der k""\x94""niglichen Mystiker!",
	"Habe ich dich erschreckt?",
	"Malcolm!",
	"Ich habe gestern von deiner Flucht geh""\x94""rt.",
	"Ich habe dich fr""\x81""her erwartet.",
	"Warum sollte ich mich beeilen?",
	"Ich herrsche ""\x81""ber dieses Land!",
	"Dein mickriger Fluch h""\x84""lt mich nicht zur""\x81""ck.",
	"So, erschlag mich doch!",
	"Ich habe nur noch wenig Magie ""\x81""brig.",
	"Ich werde dir zu Leibe r""\x81""cken, zweifle blo""\xE1"" nicht daran...",
	"...du bist jetzt aus Stein...",
	"...Ich lasse dir allein deine Augen.",
	"F""\x81""r Kyrandia vergie""\xE1""e ich nicht eine Tr""\x84""ne...",
	"...aber deine will ich dir nicht nehmen.",
	"Malcolm der Hofnarr ist ausgebrochen!",
	"Er beherrscht nun den Kyragem...",
	"...die Quelle aller Magie in Kyrandia!",
	"",
	"Wie kannst du es wagen, MICH umzuwerfen!",
	"Nicht doch, etwas Besonderes f""\x81""r dich...",
	"Was f""\x81""r ein l""\x84""cherlicher Fluch!",
	"Ich warne dich vorher.",
	"Springe nicht auf DIESEN Baum!",
	"Klettre nicht auf diesen Baum, kleines Eichh""\x94""rnchen!",
	"Buuh!",
	"So ist es viel lustiger...",
	"...nicht wahr?",
	"Ha ha ha...",
	"Sind Finger nicht 'was Tolles?",
	"Es ist gro""\xE1""artig, am Leben zu sein!",
	"Brandon!",
	"Gro""\xE1""vater! Wir haben es geschafft!",
	"Nein! DU hast es geschafft!",
	"Lang lebe K""\x94""nig Brandon!",
	"Lang leben die k""\x94""niglichen Mystiker!",
	"Bauen wir Kyrandia wieder auf!",
	"Eine gute Idee!",
	"Als meine erste k""\x94""nigliche Proklamation,...",
	"...erkl""\x84""re ich Sandalen zur offiziellen Fu""\xE1""bekleidung Kyrandias!",
	"Sehr weise, Brandon!",
	"Das Land ist nicht l""\x84""nger in Trauer!",
	"Und deine Freunde sind gerettet.",
	"Liebe Brynn...",
	"Malcolm ist ausgebrochen!",
	"Er wird bald zu mir kommen.",
	"Bitte hilf Brandon...",
	"",
	""
};

static const StringListProvider k1IntroStringsDOSCDGermanProvider = { ARRAYSIZE(k1IntroStringsDOSCDGerman), k1IntroStringsDOSCDGerman };

static const char *const k1ItemNamesDOSCDGerman[108] = {
	"Granat",
	"Amethyst",
	"Aquamarin",
	"Diamant",
	"Smaragd",
	"Perle",
	"Rubin",
	"Peridot",
	"Saphir",
	"Opal",
	"Topas",
	"Onyx",
	"Sonnenstein",
	"Mondstein",
	"Regenbogenstein",
	"Magnetstein",
	"Rose",
	"Tulpe",
	"Orchidee",
	"Silberne Rose",
	"Silberne Statuette",
	"Silberm""\x81""nze",
	"Goldm""\x81""nze",
	"Goldring",
	"Der Kelch des K""\x94""nigs",
	"Kienapfel",
	"Eichel",
	"Walnu""\xE1",
	"Immerleuchtende Feuerbeeren",
	"Feuerbeeren",
	"Feuerbeeren",
	"Feuerbeeren",
	"Feuerbeeren",
	"Feuerbeeren",
	"Fisch",
	"Fischgr""\x84""te",
	"Hammelkeule",
	"Knochen",
	"Apfel",
	"Apfelgriebsch",
	"Heidelbeeren",
	"Pilz",
	"Notiz",
	"Murmel",
	"S""\x84""ge",
	"Henkelkreuz",
	"Feder",
	"Ei",
	"Blatt",
	"Kleeblatt",
	"Sternschnuppe",
	"Kristallkugel",
	"Tr""\x84""ne",
	"Spiegel",
	"Eisst""\x81""ck",
	"Fl""\x94""te",
	"Sanduhr",
	"Eisenschl""\x81""ssel",
	"Jadeschl""\x81""ssel",
	"Obsidianschl""\x81""ssel",
	"Roter Trank",
	"Roter Trank",
	"Blauer Trank",
	"Blauer Trank",
	"Gelber Trank",
	"Gelber Trank",
	"Gr""\x81""ner Trank",
	"Oranger Trank",
	"Violetter Trank",
	"Regenbogentrank",
	"S""\x81\xE1""wasser",
	"S""\x81\xE1""wasser",
	"Salzwasser",
	"Salzwasser",
	"Mineralwasser",
	"Mineralwasser",
	"Magisches Wasser",
	"Magisches Wasser",
	"Leere Flasche",
	"Leere Flasche",
	"Schriftrolle",
	"Schriftrolle",
	"Schriftrolle",
	"Schriftrolle",
	"Schriftrolle",
	"Schriftrolle",
	"Schriftrolle",
	"Schriftrolle",
	"Schriftrolle",
	"Schriftrolle",
	"Pergamentfetzen",
	"Pergamentfetzen",
	"Pergamentfetzen",
	"Pergamentfetzen",
	"Pergamentfetzen",
	"Roter Weisenstein",
	"Oranger Weisenstein",
	"Gelber Weisenstein",
	"Gr""\x81""ner Weisenstein",
	"T""\x81""rkiser Weisenstein",
	"Blauer Weisenstein",
	"Violetter Weisenstein",
	"Schwerer Stein",
	"K""\x94""nigliche Krone",
	"K""\x94""nigliches Zepter",
	"Goldschl""\x81""ssel",
	"Unbekannter Gegenstand",
	""
};

static const StringListProvider k1ItemNamesDOSCDGermanProvider = { ARRAYSIZE(k1ItemNamesDOSCDGerman), k1ItemNamesDOSCDGerman };

static const char *const k1TakenStringsDOSCDGerman[2] = {
	" aufgenommen.",
	" aufgenommen."
};

static const StringListProvider k1TakenStringsDOSCDGermanProvider = { ARRAYSIZE(k1TakenStringsDOSCDGerman), k1TakenStringsDOSCDGerman };

static const char *const k1PlacedStringsDOSCDGerman[1] = {
	" abgelegt."
};

static const StringListProvider k1PlacedStringsDOSCDGermanProvider = { ARRAYSIZE(k1PlacedStringsDOSCDGerman), k1PlacedStringsDOSCDGerman };

static const char *const k1DroppedStringsDOSCDGerman[1] = {
	" fallengelassen."
};

static const StringListProvider k1DroppedStringsDOSCDGermanProvider = { ARRAYSIZE(k1DroppedStringsDOSCDGerman), k1DroppedStringsDOSCDGerman };

static const char *const k1NoDropStringsDOSCDGerman[2] = {
	"Hier kann nichts mehr abgelegt werden.",
	"Das kann hier nicht abgelegt werden."
};

static const StringListProvider k1NoDropStringsDOSCDGermanProvider = { ARRAYSIZE(k1NoDropStringsDOSCDGerman), k1NoDropStringsDOSCDGerman };

static const char *const k1PutDownStringDOSCDGerman[1] = {
	"Vielleicht sollte ich es erst hinlegen."
};

static const StringListProvider k1PutDownStringDOSCDGermanProvider = { ARRAYSIZE(k1PutDownStringDOSCDGerman), k1PutDownStringDOSCDGerman };

static const char *const k1WaitAmuletStringDOSCDGerman[1] = {
	"I nehme an, ich mu""\xE1"" warten, bis mein Amulett seine Kraft wiedererlangt."
};

static const StringListProvider k1WaitAmuletStringDOSCDGermanProvider = { ARRAYSIZE(k1WaitAmuletStringDOSCDGerman), k1WaitAmuletStringDOSCDGerman };

static const char *const k1BlackJewelStringDOSCDGerman[1] = {
	"Es ist ein Edelstein, aber warum ist er schwarz?"
};

static const StringListProvider k1BlackJewelStringDOSCDGermanProvider = { ARRAYSIZE(k1BlackJewelStringDOSCDGerman), k1BlackJewelStringDOSCDGerman };

static const char *const k1HealingTipStringDOSCDGerman[1] = {
	"Mann, das kann ganz n""\x81""tzlich sein, falls ich mich verletze!"
};

static const StringListProvider k1HealingTipStringDOSCDGermanProvider = { ARRAYSIZE(k1HealingTipStringDOSCDGerman), k1HealingTipStringDOSCDGerman };

static const char *const k1PoisonGoneStringDOSCDGerman[2] = {
	"Erstaunlich!",
	"Die Wirkung des Giftes hat nachgelassen!"
};

static const StringListProvider k1PoisonGoneStringDOSCDGermanProvider = { ARRAYSIZE(k1PoisonGoneStringDOSCDGerman), k1PoisonGoneStringDOSCDGerman };

static const char *const k1ThePoisonStringsDOSCDGerman[4] = {
	"Das Gift...",
	"Ich kann nicht atmen...",
	"Ich f""\x81""hle mich nicht besonders wohl...",
	"Die Schlange mu""\xE1"" \rgiftig gewesen sein!"
};

static const StringListProvider k1ThePoisonStringsDOSCDGermanProvider = { ARRAYSIZE(k1ThePoisonStringsDOSCDGerman), k1ThePoisonStringsDOSCDGerman };

static const char *const k1FluteStringsDOSCDGerman[2] = {
	"Klingt nicht besonders beeindruckend.",
	"Die letzte Note war hoch!"
};

static const StringListProvider k1FluteStringsDOSCDGermanProvider = { ARRAYSIZE(k1FluteStringsDOSCDGerman), k1FluteStringsDOSCDGerman };

static const char *const k1WispJewelStringsDOSCDGerman[3] = {
	"Im Moment f""\x81""hle ich mich dazu nicht in der Lage.",
	"Ich mu""\xE1"" wahrscheinlich erst mein(e)...",
	"ablegen."
};

static const StringListProvider k1WispJewelStringsDOSCDGermanProvider = { ARRAYSIZE(k1WispJewelStringsDOSCDGerman), k1WispJewelStringsDOSCDGerman };

static const char *const k1MagicJewelStringsDOSCDGerman[1] = {
	"Das war eigenartig."
};

static const StringListProvider k1MagicJewelStringsDOSCDGermanProvider = { ARRAYSIZE(k1MagicJewelStringsDOSCDGerman), k1MagicJewelStringsDOSCDGerman };

static const char *const k1FlaskFullStringDOSCDGerman[1] = {
	"Die Flasche ist bereits voll."
};

static const StringListProvider k1FlaskFullStringDOSCDGermanProvider = { ARRAYSIZE(k1FlaskFullStringDOSCDGerman), k1FlaskFullStringDOSCDGerman };

static const char *const k1FullFlaskStringDOSCDGerman[4] = {
	"Die Flasche ist jetzt mit \rfrischem, klarem Wasser gef""\x81""llt.",
	"Die Flasche ist jetzt mit \rSalzwasser gef""\x81""llt.",
	"Die Flasche ist jetzt mit \rMineralwasser gef""\x81""llt.",
	"Magisches Wasser."
};

static const StringListProvider k1FullFlaskStringDOSCDGermanProvider = { ARRAYSIZE(k1FullFlaskStringDOSCDGerman), k1FullFlaskStringDOSCDGerman };

static const char *const k1OutroHomeStringDOSCDGerman[1] = {
	"Ab nach Hause"
};

static const StringListProvider k1OutroHomeStringDOSCDGermanProvider = { ARRAYSIZE(k1OutroHomeStringDOSCDGerman), k1OutroHomeStringDOSCDGerman };

static const char *const k1VeryCleverStringDOSCDGerman[1] = {
	"Sehr clever! Aber nichtige Versuche sind zum Scheitern verurteilt."
};

static const StringListProvider k1VeryCleverStringDOSCDGermanProvider = { ARRAYSIZE(k1VeryCleverStringDOSCDGerman), k1VeryCleverStringDOSCDGerman };

static const char *const k1GUIStringsDOSCDGerman[59] = {
	"Die Legende von Kyrandia",
	"Ein Spiel laden",
	"Dieses Spiel sichern",
	"Spielsteuerungen",
	"Spiel beenden",
	"Spiel wieder aufnehmen",
	"Spielsteuerungen",
	"Welches Spiel soll noch einmal geladen werden?",
	"W""\x84""hlen Sie den Platz zum Sichern aus.",
	"[ LEERER PLATZ ]",
	"Abbrechen",
	"Beschreibung des gesicherten Spiels eingeben.",
	"Sichern",
	"Ruhe in Frieden, Brandon.",
	"Soll das Spiel wirklich beendet werden?",
	"XXXXX",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"XXXXX",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"XXXXXXXXXXXXXXXXX",
	"XXXXXXXXXXXXXXXXX",
	"XXXXXXXXXXXX",
	"",
	"",
	"",
	"",
	"",
	"Hauptmen\x81",
	"An",
	"Aus",
	"Ja",
	"Nein",
	"Schrittempo",
	"Textgeschwindigkeit",
	"Die Musik ist",
	"Die Soundeffekte sind",
	"Stimmen/Text"
};

static const StringListProvider k1GUIStringsDOSCDGermanProvider = { ARRAYSIZE(k1GUIStringsDOSCDGerman), k1GUIStringsDOSCDGerman };

static const char *const k1NewGameStringDOSCDGerman[1] = {
	"[ EIN NEUES SPIEL ANFANGEN ]"
};

static const StringListProvider k1NewGameStringDOSCDGermanProvider = { ARRAYSIZE(k1NewGameStringDOSCDGerman), k1NewGameStringDOSCDGerman };

static const char *const k1ConfigStringsDOSCDGerman[12] = {
	"am langsamsten",
	"langsam",
	"normal",
	"schnell",
	"am schnellsten",
	"Nur Text",
	"Nur Stimmen",
	"Stimmen & Text",
	"am langsamsten",
	"normal",
	"schnell",
	"anklickbar"
};

static const StringListProvider k1ConfigStringsDOSCDGermanProvider = { ARRAYSIZE(k1ConfigStringsDOSCDGerman), k1ConfigStringsDOSCDGerman };
